@@ -37,6 +37,15 @@ def deploy(git_origin, deployment_base_name, namespace="oda-staging", local=Fals
         descr = subprocess.check_output( # cli is more stable than python API
             ["git", "describe", "--always", "--tags"],
             cwd=local_repo_path ).decode().strip()
+        
+        author = subprocess.check_output( 
+            ["git", "log", "-1", "--pretty=format:'%an <%ae>'"], # could use all authors too, but it's inside anyway
+            cwd=local_repo_path ).decode().strip()
+            
+        last_change_time = subprocess.check_output( 
+            ["git", "log", "-1", "--pretty=format:'%ai'"], # could use all authors too, but it's inside anyway
+            cwd=local_repo_path ).decode().strip()
+            
 
         config_fn = local_repo_path / "mmoda.yaml"
 
@@ -57,6 +66,10 @@ RUN pip install -r requirements.txt
         open(pathlib.Path(tmpdir) / "Dockerfile", "a").write(f"""
 RUN pip install nb2workflow[cwl,service,rdf]=={version()}
 
+ENV ODA_WORKFLOW_VERSION="{descr}"
+ENV ODA_WORKFLOW_LAST_AUTHOR="{author}"
+ENV ODA_WORKFLOW_LAST_CHANGED="{last_change_time}"
+
 COPY nb-repo/ /repo/
 
 RUN curl -o /usr/bin/jq -L https://github.com/stedolan/jq/releases/download/jq-1.5/jq-linux64; chmod +x /usr/bin/jq
